pub struct TimestampUTC(/* private fields */);Expand description
A wrapper around the chrono crate’s DateTime<Utc> type.
Implementations
Methods from Deref<Target = DateTime<Utc>>
pub const MIN_UTC: DateTime<Utc>
pub const MAX_UTC: DateTime<Utc>
Sourcepub fn date(&self) -> Date<Tz>
👎Deprecated since 0.4.23: Use date_naive() instead
pub fn date(&self) -> Date<Tz>
date_naive() insteadRetrieves the date component with an associated timezone.
Unless you are immediately planning on turning this into a DateTime
with the same timezone you should use the date_naive method.
NaiveDate is a more well-defined type, and has more traits implemented on it,
so should be preferred to Date any time you truly want to operate on dates.
Panics
DateTime internally stores the date and time in UTC with a NaiveDateTime. This
method will panic if the offset from UTC would push the local date outside of the
representable range of a Date.
Sourcepub fn date_naive(&self) -> NaiveDate
pub fn date_naive(&self) -> NaiveDate
Retrieves the date component.
Panics
DateTime internally stores the date and time in UTC with a NaiveDateTime. This
method will panic if the offset from UTC would push the local date outside of the
representable range of a NaiveDate.
Example
use chrono::prelude::*;
let date: DateTime<Utc> = Utc.with_ymd_and_hms(2020, 1, 1, 0, 0, 0).unwrap();
let other: DateTime<FixedOffset> =
FixedOffset::east_opt(23).unwrap().with_ymd_and_hms(2020, 1, 1, 0, 0, 0).unwrap();
assert_eq!(date.date_naive(), other.date_naive());Sourcepub fn timestamp(&self) -> i64
pub fn timestamp(&self) -> i64
Returns the number of non-leap seconds since January 1, 1970 0:00:00 UTC (aka “UNIX timestamp”).
The reverse operation of creating a DateTime from a timestamp can be performed
using from_timestamp or TimeZone::timestamp_opt.
use chrono::{DateTime, TimeZone, Utc};
let dt: DateTime<Utc> = Utc.with_ymd_and_hms(2015, 5, 15, 0, 0, 0).unwrap();
assert_eq!(dt.timestamp(), 1431648000);
assert_eq!(DateTime::from_timestamp(dt.timestamp(), dt.timestamp_subsec_nanos()).unwrap(), dt);Sourcepub fn timestamp_millis(&self) -> i64
pub fn timestamp_millis(&self) -> i64
Returns the number of non-leap-milliseconds since January 1, 1970 UTC.
Example
use chrono::{NaiveDate, Utc};
let dt = NaiveDate::from_ymd_opt(1970, 1, 1)
.unwrap()
.and_hms_milli_opt(0, 0, 1, 444)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_millis(), 1_444);
let dt = NaiveDate::from_ymd_opt(2001, 9, 9)
.unwrap()
.and_hms_milli_opt(1, 46, 40, 555)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_millis(), 1_000_000_000_555);Sourcepub fn timestamp_micros(&self) -> i64
pub fn timestamp_micros(&self) -> i64
Returns the number of non-leap-microseconds since January 1, 1970 UTC.
Example
use chrono::{NaiveDate, Utc};
let dt = NaiveDate::from_ymd_opt(1970, 1, 1)
.unwrap()
.and_hms_micro_opt(0, 0, 1, 444)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_micros(), 1_000_444);
let dt = NaiveDate::from_ymd_opt(2001, 9, 9)
.unwrap()
.and_hms_micro_opt(1, 46, 40, 555)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_micros(), 1_000_000_000_000_555);Sourcepub fn timestamp_nanos(&self) -> i64
👎Deprecated since 0.4.31: use timestamp_nanos_opt() instead
pub fn timestamp_nanos(&self) -> i64
timestamp_nanos_opt() insteadReturns the number of non-leap-nanoseconds since January 1, 1970 UTC.
Panics
An i64 with nanosecond precision can span a range of ~584 years. This function panics on
an out of range DateTime.
The dates that can be represented as nanoseconds are between 1677-09-21T00:12:43.145224192 and 2262-04-11T23:47:16.854775807.
Sourcepub fn timestamp_nanos_opt(&self) -> Option<i64>
pub fn timestamp_nanos_opt(&self) -> Option<i64>
Returns the number of non-leap-nanoseconds since January 1, 1970 UTC.
Errors
An i64 with nanosecond precision can span a range of ~584 years. This function returns
None on an out of range DateTime.
The dates that can be represented as nanoseconds are between 1677-09-21T00:12:43.145224192 and 2262-04-11T23:47:16.854775807.
Example
use chrono::{NaiveDate, Utc};
let dt = NaiveDate::from_ymd_opt(1970, 1, 1)
.unwrap()
.and_hms_nano_opt(0, 0, 1, 444)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_nanos_opt(), Some(1_000_000_444));
let dt = NaiveDate::from_ymd_opt(2001, 9, 9)
.unwrap()
.and_hms_nano_opt(1, 46, 40, 555)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_nanos_opt(), Some(1_000_000_000_000_000_555));
let dt = NaiveDate::from_ymd_opt(1677, 9, 21)
.unwrap()
.and_hms_nano_opt(0, 12, 43, 145_224_192)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_nanos_opt(), Some(-9_223_372_036_854_775_808));
let dt = NaiveDate::from_ymd_opt(2262, 4, 11)
.unwrap()
.and_hms_nano_opt(23, 47, 16, 854_775_807)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_nanos_opt(), Some(9_223_372_036_854_775_807));
let dt = NaiveDate::from_ymd_opt(1677, 9, 21)
.unwrap()
.and_hms_nano_opt(0, 12, 43, 145_224_191)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_nanos_opt(), None);
let dt = NaiveDate::from_ymd_opt(2262, 4, 11)
.unwrap()
.and_hms_nano_opt(23, 47, 16, 854_775_808)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_nanos_opt(), None);Sourcepub fn timestamp_subsec_millis(&self) -> u32
pub fn timestamp_subsec_millis(&self) -> u32
Returns the number of milliseconds since the last second boundary.
In event of a leap second this may exceed 999.
Sourcepub fn timestamp_subsec_micros(&self) -> u32
pub fn timestamp_subsec_micros(&self) -> u32
Returns the number of microseconds since the last second boundary.
In event of a leap second this may exceed 999,999.
Sourcepub fn timestamp_subsec_nanos(&self) -> u32
pub fn timestamp_subsec_nanos(&self) -> u32
Returns the number of nanoseconds since the last second boundary
In event of a leap second this may exceed 999,999,999.
Sourcepub fn with_timezone<Tz2>(&self, tz: &Tz2) -> DateTime<Tz2>where
Tz2: TimeZone,
pub fn with_timezone<Tz2>(&self, tz: &Tz2) -> DateTime<Tz2>where
Tz2: TimeZone,
Changes the associated time zone.
The returned DateTime references the same instant of time from the perspective of the
provided time zone.
Sourcepub fn fixed_offset(&self) -> DateTime<FixedOffset>
pub fn fixed_offset(&self) -> DateTime<FixedOffset>
Fix the offset from UTC to its current value, dropping the associated timezone information.
This is useful for converting a generic DateTime<Tz: Timezone> to DateTime<FixedOffset>.
Sourcepub fn to_utc(&self) -> DateTime<Utc>
pub fn to_utc(&self) -> DateTime<Utc>
Turn this DateTime into a DateTime<Utc>, dropping the offset and associated timezone
information.
Sourcepub fn naive_utc(&self) -> NaiveDateTime
pub fn naive_utc(&self) -> NaiveDateTime
Returns a view to the naive UTC datetime.
Sourcepub fn naive_local(&self) -> NaiveDateTime
pub fn naive_local(&self) -> NaiveDateTime
Returns a view to the naive local datetime.
Panics
DateTime internally stores the date and time in UTC with a NaiveDateTime. This
method will panic if the offset from UTC would push the local datetime outside of the
representable range of a NaiveDateTime.
Sourcepub fn years_since(&self, base: DateTime<Tz>) -> Option<u32>
pub fn years_since(&self, base: DateTime<Tz>) -> Option<u32>
Sourcepub fn to_rfc2822(&self) -> String
pub fn to_rfc2822(&self) -> String
Returns an RFC 2822 date and time string such as Tue, 1 Jul 2003 10:52:37 +0200.
Panics
Panics if the date can not be represented in this format: the year may not be negative and can not have more than 4 digits.
Sourcepub fn to_rfc3339(&self) -> String
pub fn to_rfc3339(&self) -> String
Returns an RFC 3339 and ISO 8601 date and time string such as 1996-12-19T16:39:57-08:00.
Sourcepub fn to_rfc3339_opts(&self, secform: SecondsFormat, use_z: bool) -> String
pub fn to_rfc3339_opts(&self, secform: SecondsFormat, use_z: bool) -> String
Return an RFC 3339 and ISO 8601 date and time string with subseconds
formatted as per SecondsFormat.
If use_z is true and the timezone is UTC (offset 0), uses Z as
per Fixed::TimezoneOffsetColonZ. If use_z is false, uses
Fixed::TimezoneOffsetColon
Examples
let dt = NaiveDate::from_ymd_opt(2018, 1, 26)
.unwrap()
.and_hms_micro_opt(18, 30, 9, 453_829)
.unwrap()
.and_utc();
assert_eq!(dt.to_rfc3339_opts(SecondsFormat::Millis, false), "2018-01-26T18:30:09.453+00:00");
assert_eq!(dt.to_rfc3339_opts(SecondsFormat::Millis, true), "2018-01-26T18:30:09.453Z");
assert_eq!(dt.to_rfc3339_opts(SecondsFormat::Secs, true), "2018-01-26T18:30:09Z");
let pst = FixedOffset::east_opt(8 * 60 * 60).unwrap();
let dt = pst
.from_local_datetime(
&NaiveDate::from_ymd_opt(2018, 1, 26)
.unwrap()
.and_hms_micro_opt(10, 30, 9, 453_829)
.unwrap(),
)
.unwrap();
assert_eq!(dt.to_rfc3339_opts(SecondsFormat::Secs, true), "2018-01-26T10:30:09+08:00");Sourcepub fn with_time(&self, time: NaiveTime) -> LocalResult<DateTime<Tz>>
pub fn with_time(&self, time: NaiveTime) -> LocalResult<DateTime<Tz>>
Set the time to a new fixed time on the existing date.
Errors
Returns LocalResult::None if the datetime is at the edge of the representable range for a
DateTime, and with_time would push the value in UTC out of range.
Example
use chrono::{Local, NaiveTime};
let noon = NaiveTime::from_hms_opt(12, 0, 0).unwrap();
let today_noon = Local::now().with_time(noon);
let today_midnight = Local::now().with_time(NaiveTime::MIN);
assert_eq!(today_noon.single().unwrap().time(), noon);
assert_eq!(today_midnight.single().unwrap().time(), NaiveTime::MIN);pub const UNIX_EPOCH: DateTime<Utc>
Sourcepub fn format_with_items<'a, I, B>(&self, items: I) -> DelayedFormat<I>
pub fn format_with_items<'a, I, B>(&self, items: I) -> DelayedFormat<I>
Formats the combined date and time with the specified formatting items.
Sourcepub fn format<'a>(&self, fmt: &'a str) -> DelayedFormat<StrftimeItems<'a>>
pub fn format<'a>(&self, fmt: &'a str) -> DelayedFormat<StrftimeItems<'a>>
Formats the combined date and time per the specified format string.
See the crate::format::strftime module for the supported escape sequences.
Example
use chrono::prelude::*;
let date_time: DateTime<Utc> = Utc.with_ymd_and_hms(2017, 04, 02, 12, 50, 32).unwrap();
let formatted = format!("{}", date_time.format("%d/%m/%Y %H:%M"));
assert_eq!(formatted, "02/04/2017 12:50");Trait Implementations
Sourceimpl<'__expr> AsExpression<Nullable<TimestampUTC>> for &'__expr TimestampUTC
impl<'__expr> AsExpression<Nullable<TimestampUTC>> for &'__expr TimestampUTC
Sourcetype Expression = Bound<Nullable<TimestampUTC>, &'__expr TimestampUTC>
type Expression = Bound<Nullable<TimestampUTC>, &'__expr TimestampUTC>
Sourcefn as_expression(
self,
) -> <Self as AsExpression<Nullable<TimestampUTC>>>::Expression
fn as_expression( self, ) -> <Self as AsExpression<Nullable<TimestampUTC>>>::Expression
Sourceimpl AsExpression<Nullable<TimestampUTC>> for TimestampUTC
impl AsExpression<Nullable<TimestampUTC>> for TimestampUTC
Sourcetype Expression = Bound<Nullable<TimestampUTC>, TimestampUTC>
type Expression = Bound<Nullable<TimestampUTC>, TimestampUTC>
Sourcefn as_expression(
self,
) -> <Self as AsExpression<Nullable<TimestampUTC>>>::Expression
fn as_expression( self, ) -> <Self as AsExpression<Nullable<TimestampUTC>>>::Expression
Sourceimpl<'__expr> AsExpression<TimestampUTC> for &'__expr TimestampUTC
impl<'__expr> AsExpression<TimestampUTC> for &'__expr TimestampUTC
Sourcetype Expression = Bound<TimestampUTC, &'__expr TimestampUTC>
type Expression = Bound<TimestampUTC, &'__expr TimestampUTC>
Sourcefn as_expression(self) -> <Self as AsExpression<TimestampUTC>>::Expression
fn as_expression(self) -> <Self as AsExpression<TimestampUTC>>::Expression
Sourceimpl AsExpression<TimestampUTC> for TimestampUTC
impl AsExpression<TimestampUTC> for TimestampUTC
Sourcetype Expression = Bound<TimestampUTC, TimestampUTC>
type Expression = Bound<TimestampUTC, TimestampUTC>
Sourcefn as_expression(self) -> <Self as AsExpression<TimestampUTC>>::Expression
fn as_expression(self) -> <Self as AsExpression<TimestampUTC>>::Expression
Sourceimpl Clone for TimestampUTC
impl Clone for TimestampUTC
Sourcefn clone(&self) -> TimestampUTC
fn clone(&self) -> TimestampUTC
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TimestampUTC
impl Debug for TimestampUTC
Sourceimpl Default for TimestampUTC
impl Default for TimestampUTC
Sourceimpl Deref for TimestampUTC
impl Deref for TimestampUTC
Sourceimpl DerefMut for TimestampUTC
impl DerefMut for TimestampUTC
Sourceimpl<'de> Deserialize<'de> for TimestampUTC
impl<'de> Deserialize<'de> for TimestampUTC
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl Display for TimestampUTC
impl Display for TimestampUTC
Sourceimpl From<NaiveDateTime> for TimestampUTC
impl From<NaiveDateTime> for TimestampUTC
Sourcefn from(value: NaiveDateTime) -> Self
fn from(value: NaiveDateTime) -> Self
Sourceimpl From<TimestampUTC> for DateTime<Utc>
impl From<TimestampUTC> for DateTime<Utc>
Sourcefn from(value: TimestampUTC) -> Self
fn from(value: TimestampUTC) -> Self
Sourceimpl FromSql<TimestampUTC, Pg> for TimestampUTC
impl FromSql<TimestampUTC, Pg> for TimestampUTC
Sourceimpl FromSql<TimestampUTC, Sqlite> for TimestampUTC
impl FromSql<TimestampUTC, Sqlite> for TimestampUTC
Sourceimpl FromStr for TimestampUTC
impl FromStr for TimestampUTC
Sourceimpl Hash for TimestampUTC
impl Hash for TimestampUTC
Sourceimpl Ord for TimestampUTC
impl Ord for TimestampUTC
Sourcefn cmp(&self, other: &TimestampUTC) -> Ordering
fn cmp(&self, other: &TimestampUTC) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq for TimestampUTC
impl PartialEq for TimestampUTC
Sourceimpl PartialOrd for TimestampUTC
impl PartialOrd for TimestampUTC
Sourceimpl<__DB, __ST> Queryable<__ST, __DB> for TimestampUTC
impl<__DB, __ST> Queryable<__ST, __DB> for TimestampUTC
Sourceimpl Serialize for TimestampUTC
impl Serialize for TimestampUTC
Sourceimpl<__DB> ToSql<Nullable<TimestampUTC>, __DB> for TimestampUTC
impl<__DB> ToSql<Nullable<TimestampUTC>, __DB> for TimestampUTC
Sourceimpl ToSql<TimestampUTC, Pg> for TimestampUTC
impl ToSql<TimestampUTC, Pg> for TimestampUTC
Sourceimpl ToSql<TimestampUTC, Sqlite> for TimestampUTC
impl ToSql<TimestampUTC, Sqlite> for TimestampUTC
impl Copy for TimestampUTC
impl Eq for TimestampUTC
impl StructuralPartialEq for TimestampUTC